# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.0] - 2023-05-19
Initial toolbox functionality
### Added
 - Basic read-in functions
 - Basic functions for modifying data
 - Basic plotting functions

[unreleased]: https://github.com/upb-lea/pySignalScope/compare/0.1.0...HEAD
[0.1.0]: https://github.com/upb-lea/pySignalScope/releases/tag/0.1.0
